@@ -706,7 +706,11 @@ impl linux_pixmap {
                 dma.planes[0].offset = 0;
                 dma.handles[0].fd = DBE.wrap_fd(phy_addr, dma.planes[0].size);
             }
-            PIXMAP_FORMAT_NV21_BT601_NARROW
+            PIXMAP_FORMAT_NV12_BT601_NARROW
+            | PIXMAP_FORMAT_NV12_BT601_WIDE
+            | PIXMAP_FORMAT_NV12_BT709_NARROW
+            | PIXMAP_FORMAT_NV12_BT709_WIDE
+            | PIXMAP_FORMAT_NV21_BT601_NARROW
             | PIXMAP_FORMAT_NV21_BT601_WIDE
             | PIXMAP_FORMAT_NV21_BT709_NARROW
             | PIXMAP_FORMAT_NV21_BT709_WIDE => {
@@ -849,7 +853,11 @@ impl linux_pixmap {
                 dma.planes[0].offset = 0;
                 dma.handles[0].fd = DBE.wrap_fd(phy_addr, dma.planes[0].size);
             }
-            PIXMAP_FORMAT_NV21_BT601_NARROW
+            PIXMAP_FORMAT_NV12_BT601_NARROW
+            | PIXMAP_FORMAT_NV12_BT601_WIDE
+            | PIXMAP_FORMAT_NV12_BT709_NARROW
+            | PIXMAP_FORMAT_NV12_BT709_WIDE
+            | PIXMAP_FORMAT_NV21_BT601_NARROW
             | PIXMAP_FORMAT_NV21_BT601_WIDE
             | PIXMAP_FORMAT_NV21_BT709_NARROW
             | PIXMAP_FORMAT_NV21_BT709_WIDE => {
